import { Plugin, PluginServiceApi } from "@cloudbase/framework-core";
/**
 * 导出接口用于生成 JSON Schema 来进行智能提示
 */
interface IFrameworkPluginMiniProgramInputs {
    /**
     * 小程序应用的 appid
     */
    appid: string;
    /**
     * 小程序应用的部署私钥的本地相对路径
     *
     * @default "./private.key"
     */
    privateKeyPath: string;
    /**
     * 小程序项目的本地相对路径
     *
     * @default "./"
     */
    localPath: string;
    /**
     * 小程序应用部署时忽略的文件路径，支持通配符
     *
     * @default ["node_modules/**\/*"]
     */
    ignores?: string[];
    /**
     * 小程序应用的部署模式
     *
     * @default "preview"
     */
    deployMode?: "preview" | "upload";
    /**
     * 预览代码的选项
     */
    previewOptions?: IMiniProgramPreviewOptions;
    /**
     * 上传代码的选项
     */
    uploadOptions?: IMiniProgramUploadOptions;
}
interface IMiniProgramUploadOptions {
    /**
     * 小程序应用上传的版本号
     */
    version?: string;
    /**
     * 小程序应用的版本描述
     *
     * @default "CloudBase Framework 一键上传"
     */
    desc?: string;
    /**
     * 小程序应用的编译设置
     */
    setting?: IMiniProgramBuildSetting;
}
interface IMiniProgramPreviewOptions {
    /**
     * 小程序的版本描述
     *
     * @default "CloudBase Framework 一键预览"
     */
    desc?: string;
    /**
     * 小程序应用的编译设置
     */
    setting?: IMiniProgramBuildSetting;
    /**
     * 生成的预览二维码保存在本地的路径
     */
    qrcodeOutputPath?: string;
    /**
     * 小程序应用的预览页面地址
     *
     * @default pages/index/index
     */
    pagePath?: string;
    /**
     * 小程序应用的预览页面参数
     *
     * @default
     */
    searchQuery?: string;
    /**
     * 小程序应用的预览页面场景值
     *
     * @default 1011
     */
    scene?: number;
}
interface IMiniProgramBuildSetting {
    /**
     * 编译设置 - es6 转 es5
     *
     * @default true
     */
    es6?: boolean;
    /**
     * 编译设置 - 压缩代码
     */
    minify?: boolean;
}
declare class MiniProgramsPlugin extends Plugin {
    name: string;
    api: PluginServiceApi;
    inputs: IFrameworkPluginMiniProgramInputs;
    protected resolvedInputs: IFrameworkPluginMiniProgramInputs;
    protected buildOutput: any;
    protected ciProject: any;
    constructor(name: string, api: PluginServiceApi, inputs: IFrameworkPluginMiniProgramInputs);
    /**
     * 初始化
     */
    init(): Promise<void>;
    initCI(): void;
    /**
     * 执行本地命令
     */
    run(): Promise<void>;
    /**
     * 删除资源
     */
    remove(): Promise<void>;
    /**
     * 生成代码
     */
    genCode(): Promise<void>;
    /**
     * 构建
     */
    build(): Promise<void>;
    /**
     * 生成SAM文件
     */
    compile(): Promise<{}>;
    /**
     * 部署
     */
    deploy(): Promise<void>;
    /**
     * 小程序-上传
     */
    ciUpload(): Promise<void>;
    /**
     * 小程序-预览
     */
    ciPreview(): Promise<void>;
}
export declare const plugin: typeof MiniProgramsPlugin;
export {};
//# sourceMappingURL=index.d.ts.map